import React, { Component } from 'react';
import ModalForm from './ComponentsStudioBo/Modals/Modal';
import DataTable from './ComponentsStudioBo/Tables/DataTable';
import { CSVLink   } from "react-csv";
import axios from "axios";

class Studio extends Component {

    state = {
        items: []
    }

    getItems(){
        axios.get(`https://t2qaedohf6.execute-api.us-east-1.amazonaws.com/stud/studiobo`)
            .then(res => {
                const items = res.data;

                this.setState({ items });
                console.log("data",this.state.items);
            })
    }

    addItemToState = (item) => {
        this.setState(prevState => ({
            items: [...prevState.items, item]
        }))
    }

    updateState = (item) => {
        const itemIndex = this.state.items.findIndex(data => data.id === item.id)
        const newArray = [
            // destructure all items from beginning to the indexed item
            ...this.state.items.slice(0, itemIndex),
            // add the updated item to the array
            item,
            // add the rest of the items to the array from the index after the replaced item
            ...this.state.items.slice(itemIndex + 1)
        ]
        this.setState({ items: newArray })
    }

    deleteItemFromState = (id) => {
        const updatedItems = this.state.items.filter(item => item.id !== id)
        this.setState({ items: updatedItems })
    }

    componentDidMount(){
        this.getItems();
    }

    render() {

        return (
            <div className="App container">
                <div className="row" >
                    <div className="col-lg-12">
                        <h4 style={{margin: "20px 0"}}>Studio List</h4>
                    </div>
                </div>
                <div className="row">
                    <div className="col-lg-12">
                        <DataTable items={this.state.items} updateState={this.updateState} deleteItemFromState={this.deleteItemFromState} />
                    </div>
                </div>
                <div className="row">
                    <div className="col-lg-12">

                        { this.state.items.length !== 0 ?
                        <CSVLink
                            filename={"db.csv"}
                            color="primary"
                            style={{float: "left", marginRight: "10px"}}
                            className="btn btn-primary"
                            data={this.state.items}>
                            Download CSV
                        </CSVLink > : null }

                        <ModalForm buttonLabel="Add Studio" addItemToState={this.addItemToState}/>
                    </div>
                </div>
            </div>
        )
    }
}

export default Studio;